@media screen and (max-width:1680px){

}/*max-width:1680px*/
@media screen and (max-width:1440px){
	.welcome-hero-txt {padding: 268px 0px 122px;}
	.model-search-content {position: relative;bottom: 0;top: 100px;}
}/*max-width:1440px*/

@media screen and (max-width:1199px){
	.welcome-hero-txt h2{font-size: 40px;}
	.welcome-btn.model-search-btn {margin-left: 28px;}
	.featured-cars-img {padding: 0 10px;}
}/*max-width:1199px*/

@media screen and (max-width:1024px){

}/*max-width:1024px*/

@media screen and (max-width:1008px){

}/*max-width:1008px*/

@media screen and (max-width:992px){
	nav.navbar.bootsnav .navbar-collapse.collapse.in {padding-bottom: 30px;}
	nav.navbar.bootsnav {background-color:#000;}
	.wrap-sticky nav.navbar.bootsnav.sticked ul.nav > li > a {padding: 18px 0px;}
	nav.navbar.bootsnav .navbar-brand {padding: 25px;}
	nav.navbar.bootsnav ul.nav > li > a {padding: 15px 0px;border: transparent;}
}/*max-width:992px*/

@media screen and (max-width:991px){
	.welcome-hero-txt h2 {line-height: 1.6;}

	.model-search-content .col-sm-12 {padding: 0 40px;}
	.single-model-search:last-child {margin-bottom: 30px;}
	.welcome-btn.model-search-btn {margin: 0;}

	.single-new-cars-item {max-width: 450px; margin: 0 auto;}
	.new-cars-txt {margin: 30px 0;}
}/*max-width:991px*/

@media screen and (max-width:768px){
    
}/*max-width:768px*/

@media screen and (max-width:767px){
	.single-service-item {max-width: 350px;margin: 30px auto;}
	.single-featured-cars {max-width: 350px;margin: 0 auto;}
	.footer-social {text-align: left;}
	.footer-social a i {margin-right: 16px;margin-left: 0;}
	.hm-foot-email {max-width: 300px;}
}/*max-width:767px*/

@media screen and (max-width: 660px){

}/*max-width:660px*/

@media screen and (max-width: 640px){
	.single-testimonial-box {max-width: 350px;margin: 0 auto;}
}/*max-width:640px*/

@media screen and (max-width: 580px){

}/*max-width:580px*/

@media screen and (max-width: 540px){

}/*max-width:540px*/

@media screen and (max-width: 480px){
	.welcome-hero h2 {font-size: 30px;}
	.single-model-search h2 {font-size:16px;}
}/*max-width:480px*/

@media screen and (max-width: 440px){
	.welcome-hero-txt h2,{font-size: 24px;line-height: 1.5;}
	
}/*max-width:400px*/

@media screen and (max-width: 399px){
	.testimonial-carousel .col-sm-3, .testimonial-carousel .col-xs-12 {width: 260px;}
	.single-service-item h2 a {line-height: 1.5;}
	.section-header h2 {font-size: 30px;}
}/*max-width:399px*/

@media screen and (max-width:350px){
	nav.navbar.bootsnav .navbar-toggle {margin-right: -25px;left:-10px;}
	nav.navbar.bootsnav .navbar-brand {padding:25px 0;font-size: 20px;}
	.wrap-sticky nav.navbar.bootsnav.sticked .navbar-header a.navbar-brand, .wrap-sticky nav.navbar.bootsnav.sticked .navbar-header a.navbar-brand:hover,.wrap-sticky nav.navbar.bootsnav.sticked .navbar-header a.navbar-brand:focus {padding: 25px 0px;}
}/*max-width:350px*/

@media screen and  (max-width: 320px){
	
}/*max-width:320px*/

